<?php

namespace WireDAV\DB;

use PDO;
use PDOException;
use RuntimeException;

class PDOProvider
{
    /**
     * Creates and returns a PDO instance with configured DB connection.
     *
     * @return PDO
     * @throws RuntimeException on connection failure
     */
    public static function getPDO(): PDO
    {
        $dbHost = getenv('DB_HOST') ?: 'localhost';
        $dbPort = getenv('DB_PORT') ?: '3306';
        $dbName = getenv('DB_NAME') ?: 'sabredav';
        $dbUser = getenv('DB_USER') ?: 'sabreuser';
        $dbPass = getenv('DB_PASS') ?: 'sabrepass';
        $charset = 'utf8mb4';

        $dsn = "mysql:host=$dbHost;port=$dbPort;dbname=$dbName;charset=$charset";

        $options = [
            PDO::ATTR_ERRMODE            => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
            PDO::ATTR_EMULATE_PREPARES   => false,
        ];

        try {
            return new PDO($dsn, $dbUser, $dbPass, $options);
        } catch (PDOException $e) {
            throw new RuntimeException('Database connection failed: ' . $e->getMessage());
        }
    }
}

